@@ -58,11 +58,11 @@ properties_load(DriveData *dd)
 		dd->interval = panel_applet_gconf_get_int(PANEL_APPLET(dd->applet), "interval", NULL);
 		dd->device_pixmap = panel_applet_gconf_get_int(PANEL_APPLET(dd->applet), "pixmap", NULL);
 		dd->scale_applet = panel_applet_gconf_get_bool(PANEL_APPLET(dd->applet), "scale", NULL);
-		dd->auto_eject = panel_applet_gconf_get_bool(PANEL_APPLET(dd->applet), "auto-eject", NULL);
-		dd->mount_point = panel_applet_gconf_get_string(PANEL_APPLET(dd->applet), "mount-point", NULL);
-		dd->autofs_friendly = panel_applet_gconf_get_bool(PANEL_APPLET(dd->applet), "autofs-friendly", NULL);
-		dd->custom_icon_in = panel_applet_gconf_get_string(PANEL_APPLET(dd->applet), "custom-icon-mounted", NULL);
-		dd->custom_icon_out = panel_applet_gconf_get_string(PANEL_APPLET(dd->applet), "custom-icon-unmounted", NULL);
+		dd->auto_eject = panel_applet_gconf_get_bool(PANEL_APPLET(dd->applet), "auto_eject", NULL);
+		dd->mount_point = panel_applet_gconf_get_string(PANEL_APPLET(dd->applet), "mount_point", NULL);
+		dd->autofs_friendly = panel_applet_gconf_get_bool(PANEL_APPLET(dd->applet), "autofs_friendly", NULL);
+		dd->custom_icon_in = panel_applet_gconf_get_string(PANEL_APPLET(dd->applet), "custom_icon_mounted", NULL);
+		dd->custom_icon_out = panel_applet_gconf_get_string(PANEL_APPLET(dd->applet), "custom_icon_unmounted", NULL);
 	} else {
 		dd->mount_point = g_strdup("/mnt/floppy");
 		dd->interval = 10;
@@ -96,8 +96,9 @@ cb_mount_activate (GtkEntry *entry, gpointer data)
 	else
 		dd->mount_point = g_strdup(text);
 	
-	sync_mount_base (dd);	
-	panel_applet_gconf_set_string(PANEL_APPLET(dd->applet), "mount-point", 
+	sync_mount_base (dd);
+	redraw_pixmap (dd);	
+	panel_applet_gconf_set_string(PANEL_APPLET(dd->applet), "mount_point", 
 				      dd->mount_point, NULL);
 	g_free (text);
 	
@@ -144,7 +145,7 @@ eject_toggled (GtkToggleButton *button, gpointer data)
 	DriveData *dd = data;
 	
 	dd->auto_eject = gtk_toggle_button_get_active (button);
-	panel_applet_gconf_set_bool(PANEL_APPLET(dd->applet), "auto-eject", 
+	panel_applet_gconf_set_bool(PANEL_APPLET(dd->applet), "auto_eject", 
 				    dd->auto_eject, NULL);
 	
 }
@@ -155,7 +156,7 @@ automount_toggled (GtkToggleButton *button, gpointer data)
 	DriveData *dd = data;
 	
 	dd->autofs_friendly = gtk_toggle_button_get_active (button);
-	panel_applet_gconf_set_bool(PANEL_APPLET(dd->applet), "autofs-friendly", 
+	panel_applet_gconf_set_bool(PANEL_APPLET(dd->applet), "autofs_friendly", 
 				    dd->autofs_friendly, NULL);
 	
 }
@@ -167,7 +168,7 @@ omenu_changed (GtkOptionMenu *menu, gpointer data)
 	gint num;
 	
 	num = gtk_option_menu_get_history (menu);
-	dd->device_pixmap = num < 5 ? num : -1;
+	dd->device_pixmap = num < 6 ? num : -1;
 
 	redraw_pixmap(dd);
 	panel_applet_gconf_set_int(PANEL_APPLET(dd->applet), "pixmap", 
@@ -191,8 +192,9 @@ mount_icon_changed (GnomeIconEntry *entry, gpointer data)
 	
 	dd->device_pixmap = -1;		
 	redraw_pixmap(dd);
-	panel_applet_gconf_set_string(PANEL_APPLET(dd->applet), "custom-icon-mounted",
-				      dd->custom_icon_in, NULL);		
+	panel_applet_gconf_set_string(PANEL_APPLET(dd->applet), "custom_icon_mounted",
+				      dd->custom_icon_in, NULL);	
+		
 }
 
 static void
@@ -212,8 +214,9 @@ unmount_icon_changed (GnomeIconEntry *entry, gpointer data)
 	
 	dd->device_pixmap = -1;		
 	redraw_pixmap(dd);
-	panel_applet_gconf_set_string(PANEL_APPLET(dd->applet), "custom-icon-unmounted",
-				      dd->custom_icon_out, NULL);		
+	panel_applet_gconf_set_string(PANEL_APPLET(dd->applet), "custom_icon_unmounted",
+				      dd->custom_icon_out, NULL);
+			
 }
 
 void
@@ -233,7 +236,7 @@ properties_show(PanelApplet *applet, gpointer data)
 	gint response;
 
 	widgets = g_new0(ResponseWidgets, 1);
-	dialog = gtk_dialog_new_with_buttons(_("Disk Mounter Properties"), NULL, 
+	dialog = gtk_dialog_new_with_buttons(_("Disk Mounter Preferences"), NULL, 
 					     GTK_DIALOG_DESTROY_WITH_PARENT,
 					     GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 					     NULL);
@@ -252,11 +255,12 @@ properties_show(PanelApplet *applet, gpointer data)
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
-	label = gtk_label_new(_("Mount point:"));
+	label = gtk_label_new_with_mnemonic(_("_Mount point:"));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
 	widgets->mount_entry = gtk_entry_new_with_max_length(255);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), widgets->mount_entry);
 	gtk_entry_set_text(GTK_ENTRY(widgets->mount_entry), dd->mount_point);
 	gtk_box_pack_start(GTK_BOX(hbox), widgets->mount_entry , TRUE, TRUE, 0);
 	gtk_widget_show(widgets->mount_entry);
@@ -269,11 +273,12 @@ properties_show(PanelApplet *applet, gpointer data)
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
-	label = gtk_label_new(_("Update interval (seconds):"));
+	label = gtk_label_new_with_mnemonic(_("_Update interval (seconds):"));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
 	widgets->update_spin = gtk_spin_button_new(GTK_ADJUSTMENT(gtk_adjustment_new(dd->interval, 1.0, 30.0, 1, 1, 1)), 1, 0);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), widgets->update_spin);
 	gtk_box_pack_start(GTK_BOX(hbox), widgets->update_spin, FALSE, FALSE, 0);
 	gtk_spin_button_set_update_policy(GTK_SPIN_BUTTON(widgets->update_spin),GTK_UPDATE_ALWAYS);
 	gtk_widget_show(widgets->update_spin);
@@ -284,11 +289,12 @@ properties_show(PanelApplet *applet, gpointer data)
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
-	label = gtk_label_new(_("Icon :"));
+	label = gtk_label_new_with_mnemonic(_("_Icon :"));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
 	widgets->omenu = gtk_option_menu_new ();
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), widgets->omenu);
 	gtk_box_pack_start(GTK_BOX(hbox), widgets->omenu, TRUE, TRUE, 0);
 	gtk_widget_show(widgets->omenu);
 	menu = gtk_menu_new();
@@ -307,6 +313,9 @@ properties_show(PanelApplet *applet, gpointer data)
 	item = gtk_menu_item_new_with_label(_("Cdrom"));
 	gtk_menu_append (GTK_MENU (menu), item);
 	g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(set_widget_sensitivity_false_cb), fbox);
+	item = gtk_menu_item_new_with_label(_("Cd Recorder"));
+	gtk_menu_append (GTK_MENU (menu), item);
+	g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(set_widget_sensitivity_false_cb), fbox);
 	item = gtk_menu_item_new_with_label(_("Zip Drive"));
 	gtk_menu_append (GTK_MENU (menu), item);
 	g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(set_widget_sensitivity_false_cb), fbox);
@@ -321,7 +330,7 @@ properties_show(PanelApplet *applet, gpointer data)
 	g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(set_widget_sensitivity_true_cb), fbox);
 
 	if (dd->device_pixmap == -1)
-		gtk_option_menu_set_history(GTK_OPTION_MENU(widgets->omenu), 5);
+		gtk_option_menu_set_history(GTK_OPTION_MENU(widgets->omenu), 6);
 	else
 		gtk_option_menu_set_history(GTK_OPTION_MENU(widgets->omenu), dd->device_pixmap);
 
@@ -336,7 +345,8 @@ properties_show(PanelApplet *applet, gpointer data)
 	g_signal_connect (G_OBJECT (widgets->icon_entry_in), "changed",
 			  G_CALLBACK (mount_icon_changed), dd);
 
-	label = gtk_label_new(_("Custom icon for mounted:"));
+	label = gtk_label_new_with_mnemonic(_("Custom icon for moun_ted:"));
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), widgets->icon_entry_in);
 	gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
@@ -351,7 +361,8 @@ properties_show(PanelApplet *applet, gpointer data)
 	g_signal_connect (G_OBJECT (widgets->icon_entry_out), "changed",
 			  G_CALLBACK (unmount_icon_changed), dd);
 
-	label = gtk_label_new(_("Custom icon for not mounted:"));
+	label = gtk_label_new_with_mnemonic(_("Custom icon for not mou_nted:"));
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), widgets->icon_entry_out);
 	gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
@@ -360,21 +371,21 @@ properties_show(PanelApplet *applet, gpointer data)
 	else
 		gtk_widget_set_sensitive(fbox, FALSE);
 
-	widgets->scale_toggle = gtk_check_button_new_with_label (_("Scale size to panel"));
+	widgets->scale_toggle = gtk_check_button_new_with_mnemonic (_("_Scale size to panel"));
 	gtk_box_pack_start(GTK_BOX(vbox), widgets->scale_toggle, FALSE, FALSE, 0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widgets->scale_toggle), dd->scale_applet);
 	gtk_widget_show(widgets->scale_toggle);
 	g_signal_connect (G_OBJECT (widgets->scale_toggle), "toggled",
 			  G_CALLBACK (scale_toggled), dd);
 
-	widgets->eject_toggle = gtk_check_button_new_with_label (_("Eject on unmount"));
+	widgets->eject_toggle = gtk_check_button_new_with_mnemonic (_("_Eject on unmount"));
 	gtk_box_pack_start(GTK_BOX(vbox), widgets->eject_toggle, FALSE, FALSE, 0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widgets->eject_toggle), dd->auto_eject);
 	gtk_widget_show(widgets->eject_toggle);
 	g_signal_connect (G_OBJECT (widgets->eject_toggle), "toggled",
 			  G_CALLBACK (eject_toggled), dd);
 
-	widgets->automount_toggle = gtk_check_button_new_with_label (_("Use automount friendly status test"));
+	widgets->automount_toggle = gtk_check_button_new_with_mnemonic (_("Use _automount friendly status test"));
 	gtk_box_pack_start(GTK_BOX(vbox), widgets->automount_toggle, FALSE, FALSE, 0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widgets->automount_toggle), dd->autofs_friendly);
 	gtk_widget_show(widgets->automount_toggle);
