@@ -1,4 +1,4 @@
-/* $Id: gweather-dialog.c,v 1.16 2002/03/10 04:48:56 kevinv Exp $ */
+/* $Id: gweather-dialog.c,v 1.19 2002/04/03 01:38:28 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -265,16 +265,16 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_box_pack_end (GTK_BOX (cond_hbox), cond_frame_alignment, FALSE, FALSE, 0);
   gtk_container_set_border_width (GTK_CONTAINER (cond_frame_alignment), 2);
 
-  weather_info_get_pixmap (NULL, &(gw_applet->dialog_pixmap), &(gw_applet->dialog_mask));
-  gw_applet->cond_pixmap = gtk_pixmap_new (gw_applet->dialog_pixmap, gw_applet->dialog_mask);
-  gtk_widget_show (gw_applet->cond_pixmap);
-  gtk_container_add (GTK_CONTAINER (cond_frame_alignment), gw_applet->cond_pixmap);
+  weather_info_get_pixbuf (NULL, &(gw_applet->dialog_pixbuf));
+  gw_applet->cond_image = gtk_image_new_from_pixbuf (gw_applet->dialog_pixbuf);
+  gtk_widget_show (gw_applet->cond_image);
+  gtk_container_add (GTK_CONTAINER (cond_frame_alignment), gw_applet->cond_image);
 
   cond_vsep = gtk_vseparator_new ();
   gtk_widget_show (cond_vsep);
   gtk_box_pack_end (GTK_BOX (cond_hbox), cond_vsep, FALSE, FALSE, 0);
 
-  current_note_lbl = gtk_label_new (_("Current conditions"));
+  current_note_lbl = gtk_label_new_with_mnemonic (_("C_urrent conditions"));
   gtk_widget_show (current_note_lbl);
   gtk_notebook_set_tab_label (GTK_NOTEBOOK (weather_notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (weather_notebook), 0), current_note_lbl);
 
@@ -287,6 +287,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
 				  GTK_POLICY_AUTOMATIC);
 
   gw_applet->forecast_text = gtk_text_view_new ();
+  set_access_namedesc (gw_applet->forecast_text, _("ForeCast Report"),                                                             _("See the ForeCast Details"));
   gtk_container_add (GTK_CONTAINER (scrolled_window), gw_applet->forecast_text);
   gtk_text_view_set_editable (GTK_TEXT_VIEW (gw_applet->forecast_text), FALSE);
   gtk_text_view_set_left_margin (GTK_TEXT_VIEW (gw_applet->forecast_text), GNOME_PAD);
@@ -296,7 +297,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
 
   gtk_container_add (GTK_CONTAINER (weather_notebook), forecast_hbox);
 
-  forecast_note_lbl = gtk_label_new (_("Forecast"));
+  forecast_note_lbl = gtk_label_new_with_mnemonic (_("_Forecast"));
   gtk_widget_show (forecast_note_lbl);
   gtk_notebook_set_tab_label (GTK_NOTEBOOK (weather_notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (weather_notebook), 1), forecast_note_lbl);
 
@@ -316,9 +317,9 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
       gtk_box_pack_start (GTK_BOX (radar_vbox), ebox, FALSE, FALSE, 0);
 
 
-      gw_applet->radar_pixmap = gtk_pixmap_new (gw_applet->dialog_pixmap, gw_applet->dialog_mask);  /* Tmp hack */
-      gtk_widget_show (gw_applet->radar_pixmap);
-      gtk_container_add (GTK_CONTAINER (ebox), gw_applet->radar_pixmap);
+      gw_applet->radar_image = gtk_image_new_from_pixbuf (gw_applet->dialog_pixbuf);  /* Tmp hack */
+      gtk_widget_show (gw_applet->radar_image);
+      gtk_container_add (GTK_CONTAINER (ebox), gw_applet->radar_image);
 
       /* POP */
       gtk_widget_pop_colormap ();
@@ -328,7 +329,8 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
       gtk_widget_show (radar_link_alignment);
       gtk_box_pack_start (GTK_BOX (radar_vbox), radar_link_alignment, FALSE, FALSE, 0);
 
-      radar_link_btn = gtk_button_new_with_label (_("Visit Weather.com"));
+      radar_link_btn = gtk_button_new_with_mnemonic (_("_Visit Weather.com"));
+      set_access_namedesc (radar_link_btn, _("URL link Button"),                                                            _("Click to Enter Weather.com"));
       gtk_widget_set_usize(radar_link_btn, 450, -2);
       gtk_widget_show (radar_link_btn);
       gtk_container_add (GTK_CONTAINER (radar_link_alignment), radar_link_btn);
@@ -336,7 +338,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
       gtk_signal_connect (GTK_OBJECT (radar_link_btn), "clicked",
                           GTK_SIGNAL_FUNC (link_cb), NULL);
 
-      radar_note_lbl = gtk_label_new (_("Radar map"));
+      radar_note_lbl = gtk_label_new_with_mnemonic (_("_Radar map"));
       gtk_widget_show (radar_note_lbl);
       gtk_notebook_set_tab_label (GTK_NOTEBOOK (weather_notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (weather_notebook), 2), radar_note_lbl);
   }
@@ -383,9 +385,11 @@ void gweather_dialog_update (GWeatherApplet *gw_applet)
     if (!gw_applet->gweather_dialog)
         return;
 
-    /* Update pixmap */
-    weather_info_get_pixmap(gw_applet->gweather_info, &(gw_applet->dialog_pixmap), &(gw_applet->dialog_mask));
-    gtk_pixmap_set(GTK_PIXMAP(gw_applet->cond_pixmap), gw_applet->dialog_pixmap, gw_applet->dialog_mask);
+    /* Update pixbuf */
+    weather_info_get_pixbuf(gw_applet->gweather_info, 
+                            &(gw_applet->dialog_pixbuf));
+    gtk_image_set_from_pixbuf (GTK_IMAGE (gw_applet->cond_image), 
+                               gw_applet->dialog_pixbuf);
 
     /* Update current condition fields and forecast */
     gtk_label_set_text(GTK_LABEL(gw_applet->cond_location), weather_info_get_location(gw_applet->gweather_info));
@@ -415,7 +419,8 @@ void gweather_dialog_update (GWeatherApplet *gw_applet)
     if (gw_applet->gweather_pref.radar_enabled) {
         GdkPixmap *radar = weather_info_get_radar(gw_applet->gweather_info);
         if (radar) {
-            gtk_pixmap_set (GTK_PIXMAP(gw_applet->radar_pixmap), radar, NULL);
+            gtk_image_set_from_pixmap (GTK_IMAGE (gw_applet->radar_image), 
+                                       radar, NULL);
         }
     }
 }
