@@ -1,4 +1,4 @@
-/* $Id: gweather-pref.c,v 1.24 2002/02/03 16:55:53 kevinv Exp $ */
+/* $Id: gweather-pref.c,v 1.35 2002/04/09 12:55:57 baddog Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -24,6 +24,7 @@
 
 #include <gnome.h>
 #include <panel-applet.h>
+#include <gconf/gconf-client.h>
 
 #include "gweather.h"
 #include "gweather-pref.h"
@@ -37,6 +38,101 @@ enum
 }; 
 
 
+static void gweather_pref_set_accessibility (GWeatherApplet *gw_applet);
+
+
+/* sets up ATK Relation between the widgets */
+
+void
+add_atk_relation (GtkWidget *widget1, GtkWidget *widget2, AtkRelationType type)
+{
+    AtkObject *atk_obj1, *atk_obj2;
+    AtkRelationSet *relation_set;
+    AtkRelation *relation;
+   
+    /* If the relation is LABELLED_BY set LABEL_FOR also */
+
+    if (type == ATK_RELATION_LABELLED_BY)
+       gtk_label_set_mnemonic_widget (GTK_LABEL (widget2), widget1);
+
+    atk_obj1 = gtk_widget_get_accessible (widget1);
+    if (! GTK_IS_ACCESSIBLE (atk_obj1))
+       return;
+    atk_obj2 = gtk_widget_get_accessible (widget2);
+
+    relation_set = atk_object_ref_relation_set (atk_obj1);
+    relation = atk_relation_new (&atk_obj2, 1, type);
+    atk_relation_set_add (relation_set, relation);
+    g_object_unref (G_OBJECT (relation));
+}
+
+/* sets accessible name and description */
+
+void
+set_access_namedesc (GtkWidget *widget, const gchar *name, const gchar *desc)
+{
+    AtkObject *obj;
+
+    obj = gtk_widget_get_accessible (widget);
+    if (! GTK_IS_ACCESSIBLE (obj))
+       return;
+
+    if ( desc )
+       atk_object_set_description (obj, desc);
+    if ( name )
+       atk_object_set_name (obj, name);
+}
+
+/* sets accessible name, description, CONTROLLED_BY 
+ * and CONTROLLER_FOR relations for the components
+ * in gweather preference dialog.
+ */
+
+static void gweather_pref_set_accessibility (GWeatherApplet *gw_applet)
+{
+
+    /* Relation between components in Network page */
+
+    add_atk_relation (gw_applet->pref_net_proxy_btn, gw_applet->pref_net_proxy_url_entry,                                              ATK_RELATION_CONTROLLER_FOR);
+    add_atk_relation (gw_applet->pref_net_proxy_btn, gw_applet->pref_net_proxy_port_entry,                                              ATK_RELATION_CONTROLLER_FOR);
+    add_atk_relation (gw_applet->pref_net_proxy_btn, gw_applet->pref_net_proxy_user_entry,                                             ATK_RELATION_CONTROLLER_FOR);
+    add_atk_relation (gw_applet->pref_net_proxy_btn, gw_applet->pref_net_proxy_passwd_entry                                           , ATK_RELATION_CONTROLLER_FOR);
+    add_atk_relation (gw_applet->pref_net_proxy_btn, gw_applet->pref_net_proxy_auth_btn,                                              ATK_RELATION_CONTROLLER_FOR);
+    add_atk_relation (gw_applet->pref_net_proxy_auth_btn, gw_applet->pref_net_proxy_user_entry                                        , ATK_RELATION_CONTROLLER_FOR); 
+    add_atk_relation (gw_applet->pref_net_proxy_auth_btn,                                                            gw_applet->pref_net_proxy_passwd_entry, ATK_RELATION_CONTROLLER_FOR);
+
+
+    add_atk_relation (gw_applet->pref_net_proxy_url_entry, gw_applet->pref_net_proxy_btn,                                              ATK_RELATION_CONTROLLED_BY);
+    add_atk_relation (gw_applet->pref_net_proxy_port_entry, gw_applet->pref_net_proxy_btn,                                              ATK_RELATION_CONTROLLED_BY);
+    add_atk_relation (gw_applet->pref_net_proxy_user_entry, gw_applet->pref_net_proxy_btn,                                             ATK_RELATION_CONTROLLED_BY);
+    add_atk_relation (gw_applet->pref_net_proxy_passwd_entry, gw_applet->pref_net_proxy_btn                                            , ATK_RELATION_CONTROLLED_BY);
+    add_atk_relation (gw_applet->pref_net_proxy_auth_btn, gw_applet->pref_net_proxy_btn,                                               ATK_RELATION_CONTROLLED_BY);
+    add_atk_relation (gw_applet->pref_net_proxy_user_entry, gw_applet->pref_net_proxy_auth_btn                                         , ATK_RELATION_CONTROLLED_BY);
+    add_atk_relation (gw_applet->pref_net_proxy_passwd_entry,                                                        gw_applet->pref_net_proxy_auth_btn, ATK_RELATION_CONTROLLED_BY);
+   
+    /* Relation between components in General page */
+
+    add_atk_relation (gw_applet->pref_basic_update_btn, gw_applet->pref_basic_update_spin,                                             ATK_RELATION_CONTROLLER_FOR);
+    add_atk_relation (gw_applet->pref_basic_radar_btn, gw_applet->pref_basic_radar_url_btn,                                            ATK_RELATION_CONTROLLER_FOR);
+    add_atk_relation (gw_applet->pref_basic_radar_btn, gw_applet->pref_basic_radar_url_entry                                            , ATK_RELATION_CONTROLLER_FOR);
+
+    add_atk_relation (gw_applet->pref_basic_update_spin, gw_applet->pref_basic_update_btn,                                             ATK_RELATION_CONTROLLED_BY);
+    add_atk_relation (gw_applet->pref_basic_radar_url_btn, gw_applet->pref_basic_radar_btn,                                            ATK_RELATION_CONTROLLED_BY);
+    add_atk_relation (gw_applet->pref_basic_radar_url_entry, gw_applet->pref_basic_radar_btn                                            , ATK_RELATION_CONTROLLED_BY);
+
+    /* Accessible Name and Description for the components in Preference Dialog */
+   
+    set_access_namedesc (gw_applet->pref_tree, _("Location view"),                                                       _("Select Location from the list"));
+    set_access_namedesc (gw_applet->pref_net_proxy_url_entry, _("URL Entry"),                                            _("Enter the Location"));
+    set_access_namedesc (gw_applet->pref_net_proxy_port_entry, _("Port Entry"),                                          _("Enter the Port number"));
+    set_access_namedesc (gw_applet->pref_net_proxy_user_entry, _("User Entry"),                                           _("Enter the user name"));
+    set_access_namedesc (gw_applet->pref_net_proxy_passwd_entry, _("Password Entry"),                                     _("Enter the Password"));
+
+    set_access_namedesc (gw_applet->pref_basic_update_spin, _("Update spin button"),                                      _("Spinbutton for updating"));
+    set_access_namedesc (gw_applet->pref_basic_radar_url_entry, _("Address Entry"),                                        _("Enter the URL"));
+
+}
+
 static gint cmp_loc (const WeatherLocation *l1, const WeatherLocation *l2)
 {
     return (l1 && l2 && weather_location_equal(l1, l2)) ? 0 : 1;
@@ -46,6 +142,11 @@ static gint cmp_loc (const WeatherLocation *l1, const WeatherLocation *l2)
 static gboolean update_dialog (GWeatherApplet *gw_applet)
 {
     GtkCTreeNode *node;
+    GConfClient *client = gconf_client_get_default ();
+    gboolean use_proxy, use_proxy_auth;
+    gint proxy_port;
+    gchar *string;
+    gchar *proxy_url, *proxy_user, *proxy_psswd;
 
     g_return_val_if_fail(gw_applet->gweather_pref.location != NULL, FALSE);
 
@@ -57,36 +158,72 @@ static gboolean update_dialog (GWeatherApplet *gw_applet)
     			     gw_applet->gweather_pref.update_enabled);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gw_applet->pref_basic_metric_btn), 
     				 gw_applet->gweather_pref.use_metric);
+#if 0
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gw_applet->pref_basic_detailed_btn), 
     				 gw_applet->gweather_pref.detailed);
+#endif
 #ifdef RADARMAP
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gw_applet->pref_basic_radar_btn),
     				 gw_applet->gweather_pref.radar_enabled);
+    gtk_widget_set_sensitive (gw_applet->pref_basic_radar_url_btn, 
+    			      gw_applet->gweather_pref.radar_enabled);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gw_applet->pref_basic_radar_url_btn),
+    				 gw_applet->gweather_pref.use_custom_radar_url);
+    gtk_widget_set_sensitive (gw_applet->pref_basic_radar_url_hbox, 
+    			      gw_applet->gweather_pref.radar_enabled);
+    if (gw_applet->gweather_pref.radar)
+    	gtk_entry_set_text (GTK_ENTRY (gw_applet->pref_basic_radar_url_entry),
+    			    gw_applet->gweather_pref.radar);
 #endif /* RADARMAP */
 
+    use_proxy = gconf_client_get_bool (client, "/system/gnome-vfs/use-http-proxy", NULL);
+    use_proxy_auth = gconf_client_get_bool (client, 
+    			"/system/gnome-vfs/use-http-proxy-authorization", NULL);
+    proxy_url = gconf_client_get_string (client, "/system/gnome-vfs/http-proxy-host", NULL);
+    proxy_user = gconf_client_get_string (client, 
+    		 	"/system/gnome-vfs/http-proxy-authorization-user", NULL);
+    proxy_psswd = gconf_client_get_string (client, 
+    		 	"/system/gnome-vfs/http-proxy-authorization-password", NULL);
+    proxy_port = gconf_client_get_int (client, 
+    		 	"/system/gnome-vfs/http-proxy-port", NULL);
+
     gtk_entry_set_text(GTK_ENTRY(gw_applet->pref_net_proxy_url_entry), 
-    		       gw_applet->gweather_pref.proxy_url ? 
-    		       gw_applet->gweather_pref.proxy_url : "");
+    		       proxy_url ? 
+    		       proxy_url : "");
     gtk_entry_set_text(GTK_ENTRY(gw_applet->pref_net_proxy_passwd_entry), 
-    		       gw_applet->gweather_pref.proxy_passwd ? 
-    		       gw_applet->gweather_pref.proxy_passwd : "");
+    		       proxy_psswd ? 
+    		       proxy_psswd : "");
     gtk_entry_set_text(GTK_ENTRY(gw_applet->pref_net_proxy_user_entry), 
-    		       gw_applet->gweather_pref.proxy_user ? 
-    		       gw_applet->gweather_pref.proxy_user : "");
+    		       proxy_user ? 
+    		       proxy_user : "");
+    string = g_strdup_printf ("%d", proxy_port);
+    gtk_entry_set_text(GTK_ENTRY(gw_applet->pref_net_proxy_port_entry), 
+    		       string);
+    g_free (string);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gw_applet->pref_net_proxy_btn), 
-    				 gw_applet->gweather_pref.use_proxy);
+    				 use_proxy);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gw_applet->pref_net_proxy_auth_btn), 
+    				 use_proxy_auth);
     
     gtk_widget_set_sensitive (gw_applet->pref_net_proxy_url_entry,
-    			      gw_applet->gweather_pref.use_proxy);
+    			      use_proxy);
     gtk_widget_set_sensitive (gw_applet->pref_net_proxy_passwd_entry,
-    			      gw_applet->gweather_pref.use_proxy);
+    			      use_proxy);
     gtk_widget_set_sensitive (gw_applet->pref_net_proxy_user_entry,
-    			      gw_applet->gweather_pref.use_proxy);
-    
+    			      use_proxy);
+    gtk_widget_set_sensitive (gw_applet->pref_net_proxy_port_entry,
+    			      use_proxy);
+    			      
+    if (proxy_url)
+        g_free (proxy_url);
+    if (proxy_user)
+        g_free (proxy_user);
+    if (proxy_psswd)
+        g_free (proxy_psswd);
     return TRUE;
 }
 
-static __inline void update_string (gchar *val, gchar **str)
+static inline void update_string (gchar *val, gchar **str)
 {
     g_return_if_fail(str != NULL);
 
@@ -124,34 +261,6 @@ static gboolean check_proxy_uri (const gchar *uri)
     return TRUE;
 }
 
-/* Update gweather_pref from pref dialog */
-static gboolean update_pref (GWeatherApplet *gw_applet)
-{
-    gchar *proxy_url;
-    
-    proxy_url = (gchar *)gtk_entry_get_text(GTK_ENTRY(gw_applet->pref_net_proxy_url_entry));
-
-   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(gw_applet->pref_net_proxy_btn))
-	&& proxy_url && strlen(proxy_url) && !check_proxy_uri(proxy_url)) {
-        gnome_error_dialog(_("Proxy URL is not of the form http://host:port/\nProperties remain unchanged."));
-        return FALSE;
-    }
-
-    
-#ifdef RADARMAP
-    
-#endif /* RADARMAP */
-
-    
-    update_string(proxy_url, &(gw_applet->gweather_pref.proxy_url));
-    update_string((gchar *)gtk_entry_get_text(GTK_ENTRY(gw_applet->pref_net_proxy_passwd_entry)), &(gw_applet->gweather_pref.proxy_passwd));
-    update_string((gchar *)gtk_entry_get_text(GTK_ENTRY(gw_applet->pref_net_proxy_user_entry)), &(gw_applet->gweather_pref.proxy_user));
-
-    /* fprintf(stderr, "Set location to: %s\n", loc->name); */
-
-    return TRUE;
-}
-
 static void change_cb (GtkButton *button, gpointer user_data)
 {
     GWeatherApplet *gw_applet = user_data;
@@ -215,12 +324,16 @@ static void load_locations (GWeatherApplet *gw_applet)
     gchar *pp[1], *path;
     gint nregions, iregions;
     gchar **regions;
+    gchar *file;
     
     model = GTK_TREE_STORE (gtk_tree_view_get_model (tree));
 
-    path = g_strdup_printf("=%s=/", gnome_datadir_file("gweather/Locations"));
+    file = gnome_datadir_file("gweather/Locations");
+    g_return_if_fail (file);
+    path = g_strdup_printf("=%s=/", file);
     gnome_config_push_prefix(path);
     g_free(path);
+    g_free (file);
     
     cell_renderer = gtk_cell_renderer_text_new ();
     column = gtk_tree_view_column_new_with_attributes ("not used", cell_renderer,
@@ -319,63 +432,110 @@ static void
 proxy_toggled (GtkToggleButton *button, gpointer data)
 {
     GWeatherApplet *gw_applet = data;
+    GConfClient *client = gconf_client_get_default ();
     gboolean toggled;
 	
     toggled = gtk_toggle_button_get_active(button);
-    gw_applet->gweather_pref.use_proxy = toggled;
     gtk_widget_set_sensitive(gw_applet->pref_net_proxy_url_entry, toggled);
     gtk_widget_set_sensitive(gw_applet->pref_net_proxy_user_entry, toggled);
+    gtk_widget_set_sensitive(gw_applet->pref_net_proxy_port_entry, toggled);
     gtk_widget_set_sensitive(gw_applet->pref_net_proxy_passwd_entry, toggled);
+    gtk_widget_set_sensitive(gw_applet->pref_net_proxy_auth_btn, toggled);
+
+    gconf_client_set_bool (client, "/system/gnome-vfs/use-http-proxy", 
+    			   toggled, NULL);
+}
+
+static gboolean
+proxy_port_changed (GtkWidget *entry, GdkEventFocus *event, gpointer data)
+{
+    GWeatherApplet *gw_applet = data;
+    GConfClient *client = gconf_client_get_default ();
+    gchar *text;
+    gint port;
+
+    text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
     
-    panel_applet_gconf_set_bool(gw_applet->applet, "enable_proxy", toggled, NULL);
+    if (!text) 
+    	return FALSE;
+    port = atoi (text);
+    g_free (text);
+    
+    gconf_client_set_int (client, "/system/gnome-vfs/http-proxy-port", 
+    			  port, NULL);
+
+    return FALSE;
 }
 
 static void
+proxy_auth_toggled (GtkToggleButton *button, gpointer data)
+{
+    GWeatherApplet *gw_applet = data;
+    GConfClient *client = gconf_client_get_default ();
+    gboolean toggled;
+	
+    toggled = gtk_toggle_button_get_active(button);
+    gtk_widget_set_sensitive(gw_applet->pref_net_proxy_user_entry, toggled);
+    gtk_widget_set_sensitive(gw_applet->pref_net_proxy_passwd_entry, toggled);
+    gconf_client_set_bool (client, "/system/gnome-vfs/use-http-proxy-authorization", 
+    			   toggled, NULL);
+}
+
+static gboolean
 proxy_url_changed (GtkWidget *entry, GdkEventFocus *event, gpointer data)
 {
     GWeatherApplet *gw_applet = data;
+    GConfClient *client = gconf_client_get_default ();
     gchar *text;
-	g_print("url_changed\n");    
+
     text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
     
-   if (!text)
-   	return;
-   
-   panel_applet_gconf_set_string(gw_applet->applet, "proxy_url", text, NULL);
-   g_free(gw_applet->gweather_pref.proxy_url);
-   gw_applet->gweather_pref.proxy_url = text;   	
+    if (!text) 
+    	return FALSE;
+    
+    gconf_client_set_string (client, "/system/gnome-vfs/http-proxy-host", 
+    			     text, NULL);
+    g_free (text);
+    
+    return FALSE;
 }
 
-static void
+static gboolean
 proxy_user_changed (GtkWidget *entry, GdkEventFocus *event, gpointer data)
 {
     GWeatherApplet *gw_applet = data;
+    GConfClient *client = gconf_client_get_default ();
     gchar *text;
-    
+   
     text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
     
-   if (!text)
-   	return;
-   
-   panel_applet_gconf_set_string(gw_applet->applet, "proxy_user", text, NULL);
-   g_free(gw_applet->gweather_pref.proxy_user);
-   gw_applet->gweather_pref.proxy_user = text;   
+    if (!text)
+   	return FALSE;
+
+    gconf_client_set_string (client, "/system/gnome-vfs/http-proxy-authorization-user", 
+    			     text, NULL); 
+    g_free (text);
+
+    return FALSE;
 }
 
-static void
+static gboolean
 proxy_password_changed (GtkWidget *entry, GdkEventFocus *event, gpointer data)
 {
     GWeatherApplet *gw_applet = data;
+    GConfClient *client = gconf_client_get_default ();
     gchar *text;
-    
+   
     text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
     
-   if (!text)
-   	return;
+    if (!text)
+   	return FALSE;
 
-	panel_applet_gconf_set_string(gw_applet->applet, "proxy_passwd", text, NULL);
-	g_free(gw_applet->gweather_pref.proxy_passwd);
-	gw_applet->gweather_pref.proxy_passwd = text;      	
+    gconf_client_set_string (client, "/system/gnome-vfs/http-proxy-authorization-password", 
+    			     text, NULL);
+    g_free (text);
+    
+    return FALSE;
 }
 
 static void
@@ -388,6 +548,12 @@ auto_update_toggled (GtkToggleButton *button, gpointer data)
     gw_applet->gweather_pref.update_enabled = toggled;
     gtk_widget_set_sensitive (gw_applet->pref_basic_update_spin, toggled);
     panel_applet_gconf_set_bool(gw_applet->applet, "auto_update", toggled, NULL);
+    if (gw_applet->timeout_tag > 0)
+        gtk_timeout_remove(gw_applet->timeout_tag);
+    if (gw_applet->gweather_pref.update_enabled)
+        gw_applet->timeout_tag =  
+        	gtk_timeout_add (gw_applet->gweather_pref.update_interval * 1000,
+                                 timeout_cb, gw_applet);
 }
 
 static void
@@ -397,8 +563,24 @@ metric_toggled (GtkToggleButton *button, gpointer data)
     gboolean toggled;
     
     toggled = gtk_toggle_button_get_active(button);
+    if (gw_applet->gweather_pref.use_metric == toggled)
+        return;
+        
     gw_applet->gweather_pref.use_metric = toggled;
     panel_applet_gconf_set_bool(gw_applet->applet, "enable_metric", toggled, NULL);
+    
+    if (!gw_applet->gweather_info)
+        return;
+    
+    if (gw_applet->gweather_pref.use_metric) {
+        weather_info_to_metric (gw_applet->gweather_info);
+    }
+    else {    
+        weather_info_to_imperial (gw_applet->gweather_info); 
+    }
+    gtk_label_set_text(GTK_LABEL(gw_applet->label), 
+    		       weather_info_get_temp_summary(gw_applet->gweather_info));
+    gweather_dialog_update (gw_applet); 
 }
 
 static void
@@ -409,7 +591,8 @@ detailed_toggled (GtkToggleButton *button, gpointer data)
     
     toggled = gtk_toggle_button_get_active(button);
     gw_applet->gweather_pref.detailed = toggled;
-    panel_applet_gconf_set_bool(gw_applet->applet, "enable_detailed_forecast", toggled, NULL);    
+    panel_applet_gconf_set_bool(gw_applet->applet, "enable_detailed_forecast", 
+    				toggled, NULL);    
 }
 
 static void
@@ -421,6 +604,44 @@ radar_toggled (GtkToggleButton *button, gpointer data)
     toggled = gtk_toggle_button_get_active(button);
     gw_applet->gweather_pref.radar_enabled = toggled;
     panel_applet_gconf_set_bool(gw_applet->applet, "enable_radar_map", toggled, NULL);
+    gtk_widget_set_sensitive (gw_applet->pref_basic_radar_url_btn, toggled);
+    gtk_widget_set_sensitive (gw_applet->pref_basic_radar_url_hbox, toggled);
+}
+
+static void
+use_radar_url_toggled (GtkToggleButton *button, gpointer data)
+{
+    GWeatherApplet *gw_applet = data;
+    gboolean toggled;
+    
+    toggled = gtk_toggle_button_get_active(button);
+    gw_applet->gweather_pref.use_custom_radar_url = toggled;
+    panel_applet_gconf_set_bool(gw_applet->applet, "use_custom_radar_url", toggled, NULL);
+}
+
+static gboolean
+radar_url_changed (GtkWidget *widget, GdkEventFocus *event, gpointer data)
+{
+    GWeatherApplet *gw_applet = data;
+    gchar *text;
+    
+    text = gtk_editable_get_chars (GTK_EDITABLE (widget), 0, -1);
+    
+    if (gw_applet->gweather_pref.radar)
+        g_free (gw_applet->gweather_pref.radar);
+        
+    if (text) {
+    	gw_applet->gweather_pref.radar = g_strdup (text);
+    	g_free (text);
+    }
+    else
+    	gw_applet->gweather_pref.radar = NULL;
+    	
+    panel_applet_gconf_set_string (gw_applet->applet, "radar", 
+    				   gw_applet->gweather_pref.radar, NULL);
+    				   
+    return FALSE;
+    				   
 }
 
 static void
@@ -429,17 +650,25 @@ update_interval_changed (GtkSpinButton *button, gpointer data)
     GWeatherApplet *gw_applet = data;
     
     gw_applet->gweather_pref.update_interval = gtk_spin_button_get_value_as_int(button)*60;
-    panel_applet_gconf_set_int(gw_applet->applet, "auto_update_intervarl", 
-    		gw_applet->gweather_pref.update_interval, NULL);
+    panel_applet_gconf_set_int(gw_applet->applet, "auto_update_interval", 
+    		               gw_applet->gweather_pref.update_interval, NULL);
+    if (gw_applet->timeout_tag > 0)
+        gtk_timeout_remove(gw_applet->timeout_tag);
+    if (gw_applet->gweather_pref.update_enabled)
+        gw_applet->timeout_tag =  
+        	gtk_timeout_add (gw_applet->gweather_pref.update_interval * 1000,
+                                 timeout_cb, gw_applet);
 }
 
 static void
 response_cb (GtkDialog *dialog, gint id, gpointer data)
 {
     GWeatherApplet *gw_applet = data;
-    gtk_widget_destroy (GTK_WIDGET (dialog));
-    gw_applet->pref = NULL;
-     
+    gtk_widget_hide (GTK_WIDGET (dialog));
+#if 0
+    /* refresh the applet incase the location has changed */
+    gweather_update(gw_applet);
+#endif
 }
 
 static void gweather_pref_create (GWeatherApplet *gw_applet)
@@ -450,6 +679,8 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
     GtkWidget *pref_basic_detailed_alignment;
 #ifdef RADARMAP
     GtkWidget *pref_basic_radar_alignment;
+    GtkWidget *pref_basic_radar_url_alignment;
+    GtkWidget *pref_basic_radar_url_entry_alignment;
 #endif /* RADARMAP */
     GtkWidget *pref_basic_update_alignment;
     GtkWidget *pref_basic_update_lbl;
@@ -457,23 +688,23 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
     GtkObject *pref_basic_update_spin_adj;
     GtkWidget *pref_basic_update_sec_lbl;
     GtkWidget *pref_basic_note_lbl;
-    GtkWidget *pref_net_table;
+    GtkWidget *proxy_box;
     GtkWidget *pref_net_note_lbl;
     GtkWidget *pref_net_proxy_url_lbl;
+    GtkWidget *pref_net_proxy_port_lbl;
     GtkWidget *pref_net_proxy_user_lbl;
     GtkWidget *pref_net_proxy_passwd_lbl;
-    GtkWidget *pref_net_proxy_alignment;
-    GtkWidget *pref_net_caveat_lbl;
     GtkWidget *pref_loc_hbox;
     GtkWidget *pref_loc_note_lbl;
     GtkWidget *scrolled_window;
+    GtkWidget *label, *hbox;
     GtkTreeStore *model;
     GtkTreeSelection *selection;
     GtkWidget *pref_basic_vbox;
     GtkWidget *vbox;
     GtkWidget *frame;
-
-    gw_applet->pref = gtk_dialog_new_with_buttons (_("Weather Properties"), NULL,
+    
+    gw_applet->pref = gtk_dialog_new_with_buttons (_("Weather Preferences"), NULL,
 				      		   GTK_DIALOG_DESTROY_WITH_PARENT,
 				      		   GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 				      		   NULL);
@@ -518,90 +749,98 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
     gtk_box_pack_start (GTK_BOX (pref_loc_hbox), scrolled_window, TRUE, TRUE, 0);
     load_locations(gw_applet);
 
-    pref_loc_note_lbl = gtk_label_new (_("Location"));
+    pref_loc_note_lbl = gtk_label_new_with_mnemonic (_("_Location"));
     gtk_widget_show (pref_loc_note_lbl);
     gtk_notebook_set_tab_label (GTK_NOTEBOOK (pref_notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (pref_notebook), 0), pref_loc_note_lbl);
 
     /*
    * Network settings page.
    */
-    pref_net_table = gtk_table_new (5, 2, FALSE);
-    gtk_widget_show (pref_net_table);
-    gtk_container_add (GTK_CONTAINER (pref_notebook), pref_net_table);
-    gtk_container_set_border_width (GTK_CONTAINER (pref_net_table), 8);
-    gtk_table_set_row_spacings (GTK_TABLE (pref_net_table), 4);
-    gtk_table_set_col_spacings (GTK_TABLE (pref_net_table), 4);
-
-    pref_net_proxy_alignment = gtk_alignment_new (0, 0.5, 0, 1);
-    gtk_widget_show (pref_net_proxy_alignment);
-    gtk_table_attach (GTK_TABLE (pref_net_table), pref_net_proxy_alignment, 0, 2, 0, 1,
-		      (GtkAttachOptions) (GTK_FILL),
-		      (GtkAttachOptions) (0), 0, 0);
-
-    gw_applet->pref_net_proxy_btn = gtk_check_button_new_with_label (_("Use proxy"));
+    proxy_box = gtk_vbox_new (FALSE, 2);
+    gtk_widget_show (proxy_box);
+    gtk_container_set_border_width (GTK_CONTAINER (proxy_box), 8);
+    gtk_container_add (GTK_CONTAINER (pref_notebook), proxy_box);
+    
+    gw_applet->pref_net_proxy_btn = gtk_check_button_new_with_mnemonic (_("_Use HTTP proxy"));
     gtk_widget_show (gw_applet->pref_net_proxy_btn);
-    gtk_container_add (GTK_CONTAINER (pref_net_proxy_alignment), gw_applet->pref_net_proxy_btn);
+    gtk_box_pack_start (GTK_BOX (proxy_box), gw_applet->pref_net_proxy_btn, 
+    			FALSE, FALSE, 0);
     g_signal_connect (G_OBJECT (gw_applet->pref_net_proxy_btn), "toggled",
     		       G_CALLBACK (proxy_toggled), gw_applet);
 
-    pref_net_proxy_url_lbl = gtk_label_new (_("Proxy URL:"));
+    hbox = gtk_hbox_new (FALSE, 2);
+    gtk_widget_show (hbox);
+    gtk_box_pack_start (GTK_BOX (proxy_box), hbox, FALSE, FALSE, 0);
+    
+    pref_net_proxy_url_lbl = gtk_label_new_with_mnemonic (_("Locat_ion :"));
     gtk_widget_show (pref_net_proxy_url_lbl);
-    gtk_table_attach (GTK_TABLE (pref_net_table), pref_net_proxy_url_lbl, 0, 1, 1, 2,
-		      (GtkAttachOptions) (GTK_FILL),
-		      (GtkAttachOptions) (0), 0, 0);
-    gtk_label_set_justify (GTK_LABEL (pref_net_proxy_url_lbl), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (pref_net_proxy_url_lbl), 1, 0.5);
+    gtk_box_pack_start (GTK_BOX (hbox), pref_net_proxy_url_lbl, 
+    			FALSE, FALSE, 0);
     
     gw_applet->pref_net_proxy_url_entry = gtk_entry_new ();
     gtk_widget_show (gw_applet->pref_net_proxy_url_entry);
-    gtk_table_attach (GTK_TABLE (pref_net_table), gw_applet->pref_net_proxy_url_entry, 1, 2, 1, 2,
-		      (GtkAttachOptions) (GTK_FILL),
-		      (GtkAttachOptions) (GTK_FILL), 0, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), gw_applet->pref_net_proxy_url_entry, 
+    			FALSE, FALSE, 0);
     g_signal_connect (G_OBJECT (gw_applet->pref_net_proxy_url_entry), "focus_out_event",
     		      G_CALLBACK (proxy_url_changed), gw_applet);
 
-    pref_net_proxy_user_lbl = gtk_label_new (_("Username:"));
+    hbox = gtk_hbox_new (FALSE, 2);
+    gtk_widget_show (hbox);
+    gtk_box_pack_start (GTK_BOX (proxy_box), hbox, FALSE, FALSE, 0);
+    
+    pref_net_proxy_port_lbl = gtk_label_new_with_mnemonic (_("P_ort :"));
+    gtk_widget_show (pref_net_proxy_port_lbl);
+    gtk_box_pack_start (GTK_BOX (hbox),  pref_net_proxy_port_lbl, 
+    			FALSE, FALSE, 0);
+    			
+    gw_applet->pref_net_proxy_port_entry = gtk_entry_new ();
+    gtk_widget_show (gw_applet->pref_net_proxy_port_entry);
+    gtk_box_pack_start (GTK_BOX (hbox), gw_applet->pref_net_proxy_port_entry, 
+    			FALSE, FALSE, 0);
+    g_signal_connect (G_OBJECT (gw_applet->pref_net_proxy_port_entry), "focus_out_event",
+    		      G_CALLBACK (proxy_port_changed), gw_applet);
+    
+    gw_applet->pref_net_proxy_auth_btn = gtk_check_button_new_with_mnemonic (_("Pro_xy requires a username and password"));
+    gtk_widget_show (gw_applet->pref_net_proxy_auth_btn);
+    gtk_box_pack_start (GTK_BOX (proxy_box), gw_applet->pref_net_proxy_auth_btn, 
+    			FALSE, FALSE, 0);
+    g_signal_connect (G_OBJECT (gw_applet->pref_net_proxy_auth_btn), "toggled",
+    		       G_CALLBACK (proxy_auth_toggled), gw_applet);
+    		       
+    hbox = gtk_hbox_new (FALSE, 2);
+    gtk_widget_show (hbox);
+    gtk_box_pack_start (GTK_BOX (proxy_box), hbox, FALSE, FALSE, 0);
+    
+    pref_net_proxy_user_lbl = gtk_label_new_with_mnemonic (_("Us_ername:"));
     gtk_widget_show (pref_net_proxy_user_lbl);
-    gtk_table_attach (GTK_TABLE (pref_net_table), pref_net_proxy_user_lbl, 0, 1, 2, 3,
-		      (GtkAttachOptions) (GTK_FILL),
-		      (GtkAttachOptions) (0), 0, 0);
-    gtk_label_set_justify (GTK_LABEL (pref_net_proxy_user_lbl), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (pref_net_proxy_user_lbl), 1, 0.5);
-
+    gtk_box_pack_start (GTK_BOX (hbox), pref_net_proxy_user_lbl, 
+    			FALSE, FALSE, 0);
+    
     gw_applet->pref_net_proxy_user_entry = gtk_entry_new ();
     gtk_widget_show (gw_applet->pref_net_proxy_user_entry);
-    gtk_table_attach (GTK_TABLE (pref_net_table), gw_applet->pref_net_proxy_user_entry, 1, 2, 2, 3,
-		      (GtkAttachOptions) (GTK_FILL),
-		      (GtkAttachOptions) (GTK_FILL), 0, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), gw_applet->pref_net_proxy_user_entry, 
+    			FALSE, FALSE, 0);
     g_signal_connect (G_OBJECT (gw_applet->pref_net_proxy_user_entry), "focus_out_event",
     		      G_CALLBACK (proxy_user_changed), gw_applet);
 
-    pref_net_proxy_passwd_lbl = gtk_label_new (_("Password:"));
+    hbox = gtk_hbox_new (FALSE, 2);
+    gtk_widget_show (hbox);
+    gtk_box_pack_start (GTK_BOX (proxy_box), hbox, FALSE, FALSE, 0);
+    
+    pref_net_proxy_passwd_lbl = gtk_label_new_with_mnemonic (_("Pass_word:"));
     gtk_widget_show (pref_net_proxy_passwd_lbl);
-    gtk_table_attach (GTK_TABLE (pref_net_table), pref_net_proxy_passwd_lbl, 0, 1, 3, 4,
-		      (GtkAttachOptions) (GTK_FILL),
-		      (GtkAttachOptions) (0), 0, 0);
-    gtk_label_set_justify (GTK_LABEL (pref_net_proxy_passwd_lbl), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (pref_net_proxy_passwd_lbl), 1, 0.5);
+    gtk_box_pack_start (GTK_BOX (hbox), pref_net_proxy_passwd_lbl, 
+    			FALSE, FALSE, 0);
 
     gw_applet->pref_net_proxy_passwd_entry = gtk_entry_new ();
     gtk_entry_set_visibility (GTK_ENTRY (gw_applet->pref_net_proxy_passwd_entry), FALSE);
     gtk_widget_show (gw_applet->pref_net_proxy_passwd_entry);
-    gtk_table_attach (GTK_TABLE (pref_net_table), gw_applet->pref_net_proxy_passwd_entry, 1, 2, 3, 4,
-		      (GtkAttachOptions) (GTK_FILL),
-		      (GtkAttachOptions) (GTK_FILL), 0, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), gw_applet->pref_net_proxy_passwd_entry, 
+    			FALSE, FALSE, 0);
     g_signal_connect (G_OBJECT (gw_applet->pref_net_proxy_passwd_entry), "focus_out_event",
     		      G_CALLBACK (proxy_password_changed), gw_applet);
 
-    pref_net_caveat_lbl = gtk_label_new (_("Warning: Your password will be saved as\nunencrypted text in a private configuration\nfile."));
-    gtk_widget_show (pref_net_caveat_lbl);
-    gtk_table_attach (GTK_TABLE (pref_net_table), pref_net_caveat_lbl, 0, 2, 4, 5,
-		      (GtkAttachOptions) (GTK_FILL),
-		      (GtkAttachOptions) (0), 0, 0);
-    gtk_label_set_justify (GTK_LABEL (pref_net_caveat_lbl), GTK_JUSTIFY_LEFT);
-    gtk_misc_set_alignment (GTK_MISC (pref_net_caveat_lbl), 1, 0.5);
-
-    pref_net_note_lbl = gtk_label_new (_("Network"));
+    pref_net_note_lbl = gtk_label_new_with_mnemonic (_("_Proxy"));
     gtk_widget_show (pref_net_note_lbl);
     gtk_notebook_set_tab_label (GTK_NOTEBOOK (pref_notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (pref_notebook), 1), pref_net_note_lbl);
 
@@ -624,32 +863,58 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
 #ifdef RADARMAP
     pref_basic_radar_alignment = gtk_alignment_new (0, 0.5, 0, 1);
     gtk_widget_show (pref_basic_radar_alignment);
+    pref_basic_radar_url_alignment = gtk_alignment_new (0.1, 0.5, 0, 1);
+    gtk_widget_show (pref_basic_radar_url_alignment);
+    pref_basic_radar_url_entry_alignment = gtk_alignment_new (0.1, 0.5, 0, 1);
+    gtk_widget_show (pref_basic_radar_url_entry_alignment);
 #endif /* RADARMAP */
 
-    gw_applet->pref_basic_update_btn = gtk_check_button_new_with_label (_("Automatically update every"));
+    gw_applet->pref_basic_update_btn = gtk_check_button_new_with_mnemonic (_("_Automatically update every"));
     gtk_widget_show (gw_applet->pref_basic_update_btn);
     gtk_container_add (GTK_CONTAINER (pref_basic_update_alignment), gw_applet->pref_basic_update_btn);
     g_signal_connect (G_OBJECT (gw_applet->pref_basic_update_btn), "toggled",
     		      G_CALLBACK (auto_update_toggled), gw_applet);
 
-    gw_applet->pref_basic_metric_btn = gtk_check_button_new_with_label (_("Use metric system units"));
+    gw_applet->pref_basic_metric_btn = gtk_check_button_new_with_mnemonic (_("Use _metric system units"));
     gtk_widget_show (gw_applet->pref_basic_metric_btn);
     gtk_container_add (GTK_CONTAINER (pref_basic_metric_alignment), gw_applet->pref_basic_metric_btn);
     g_signal_connect (G_OBJECT (gw_applet->pref_basic_metric_btn), "toggled",
     		      G_CALLBACK (metric_toggled), gw_applet);
-    		      
-    gw_applet->pref_basic_detailed_btn = gtk_check_button_new_with_label (_("Enable detailed forecast"));
+#if 0   		      
+    gw_applet->pref_basic_detailed_btn = gtk_check_button_new_with_mnemonic (_("Enable _detailed forecast"));
     gtk_widget_show (gw_applet->pref_basic_detailed_btn);
     gtk_container_add (GTK_CONTAINER (pref_basic_detailed_alignment), gw_applet->pref_basic_detailed_btn);
     g_signal_connect (G_OBJECT (gw_applet->pref_basic_detailed_btn), "toggled",
     		      G_CALLBACK (detailed_toggled), gw_applet);
-
+#endif
 #ifdef RADARMAP
-    gw_applet->pref_basic_radar_btn = gtk_check_button_new_with_label (_("Enable radar map"));
+    gw_applet->pref_basic_radar_btn = gtk_check_button_new_with_mnemonic (_("Enable _radar map"));
     gtk_widget_show (gw_applet->pref_basic_radar_btn);
     gtk_container_add (GTK_CONTAINER (pref_basic_radar_alignment), gw_applet->pref_basic_radar_btn);
     g_signal_connect (G_OBJECT (gw_applet->pref_basic_radar_btn), "toggled",
     		      G_CALLBACK (radar_toggled), gw_applet);
+    		      
+    gw_applet->pref_basic_radar_url_btn = gtk_check_button_new_with_mnemonic (_("Use cus_tom address for radar map"));
+    gtk_widget_show (gw_applet->pref_basic_radar_url_btn);
+    gtk_container_add (GTK_CONTAINER (pref_basic_radar_url_alignment), 
+    		       gw_applet->pref_basic_radar_url_btn);
+    g_signal_connect (G_OBJECT (gw_applet->pref_basic_radar_url_btn), "toggled",
+    		      G_CALLBACK (use_radar_url_toggled), gw_applet);
+    		      
+    gw_applet->pref_basic_radar_url_hbox = gtk_hbox_new (FALSE, 4);
+    gtk_widget_show (gw_applet->pref_basic_radar_url_hbox);
+    gtk_container_add (GTK_CONTAINER (pref_basic_radar_url_entry_alignment), 
+    		       gw_applet->pref_basic_radar_url_hbox);
+    label = gtk_label_new_with_mnemonic (_("A_ddress :"));
+    gtk_widget_show (label);
+    gtk_box_pack_start (GTK_BOX (gw_applet->pref_basic_radar_url_hbox),
+    			label, FALSE, FALSE, 0); 
+    gw_applet->pref_basic_radar_url_entry = gtk_entry_new ();
+    gtk_widget_show (gw_applet->pref_basic_radar_url_entry);
+    gtk_box_pack_start (GTK_BOX (gw_applet->pref_basic_radar_url_hbox),
+    			gw_applet->pref_basic_radar_url_entry, TRUE, TRUE, 0);    
+    g_signal_connect (G_OBJECT (gw_applet->pref_basic_radar_url_entry), "focus_out_event",
+    		      G_CALLBACK (radar_url_changed), gw_applet);
 #endif /* RADARMAP */
 
     frame = gtk_frame_new (_("Updates"));
@@ -658,7 +923,7 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
     pref_basic_update_hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
     gtk_container_border_width (GTK_CONTAINER (pref_basic_update_hbox), GNOME_PAD_SMALL);
 
-    pref_basic_update_lbl = gtk_label_new (_("Automatically update every "));
+    pref_basic_update_lbl = gtk_label_new_with_mnemonic (_("_Automatically update every "));
     gtk_widget_show (pref_basic_update_lbl);
     
 
@@ -695,22 +960,43 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
     vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
     gtk_container_border_width (GTK_CONTAINER (vbox), GNOME_PAD_SMALL);
 
-    gtk_box_pack_start (GTK_BOX (vbox), pref_basic_metric_alignment, FALSE, TRUE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), pref_basic_detailed_alignment, FALSE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), pref_basic_metric_alignment, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), pref_basic_detailed_alignment, TRUE, TRUE, 0);
 #ifdef RADARMAP
-    gtk_box_pack_start (GTK_BOX (vbox), pref_basic_radar_alignment, FALSE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), pref_basic_radar_alignment, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), pref_basic_radar_url_alignment, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), pref_basic_radar_url_entry_alignment, TRUE, 
+    			TRUE, 0);
 #endif /* RADARMAP */
 
     gtk_container_add (GTK_CONTAINER (frame), vbox);
     gtk_box_pack_start (GTK_BOX (pref_basic_vbox), frame, FALSE, TRUE, 0);
 
-    pref_basic_note_lbl = gtk_label_new (_("General"));
+    pref_basic_note_lbl = gtk_label_new_with_mnemonic (_("_General"));
     gtk_widget_show (pref_basic_note_lbl);
-    gtk_notebook_set_tab_label (GTK_NOTEBOOK (pref_notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (pref_notebook), 2), pref_basic_note_lbl);
+    gtk_notebook_set_tab_label (GTK_NOTEBOOK (pref_notebook), 
+    				gtk_notebook_get_nth_page (GTK_NOTEBOOK (pref_notebook), 2),
+    				pref_basic_note_lbl);
 
 
     g_signal_connect (G_OBJECT (gw_applet->pref), "response",
     		      G_CALLBACK (response_cb), gw_applet);
+   
+    gweather_pref_set_accessibility (gw_applet); 
+    add_atk_relation (gw_applet->pref_net_proxy_url_entry, pref_net_proxy_url_lbl,      
+                                            ATK_RELATION_LABELLED_BY);
+    add_atk_relation (gw_applet->pref_net_proxy_port_entry,  pref_net_proxy_port_lbl,      
+                                             ATK_RELATION_LABELLED_BY);
+    add_atk_relation (gw_applet->pref_net_proxy_passwd_entry, pref_net_proxy_passwd_lbl,   
+                                            ATK_RELATION_LABELLED_BY);
+    add_atk_relation (gw_applet->pref_net_proxy_user_entry, pref_net_proxy_user_lbl,       
+                                            ATK_RELATION_LABELLED_BY);
+    add_atk_relation (gw_applet->pref_basic_update_spin, pref_basic_update_sec_lbl,        
+                                            ATK_RELATION_LABELLED_BY);
+    add_atk_relation (gw_applet->pref_basic_radar_url_entry, label, ATK_RELATION_LABELLED_BY
+);
+ 
+
 
     gtk_widget_show_all (gw_applet->pref);
 }
@@ -718,7 +1004,6 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
 
 void gweather_pref_load (GWeatherApplet *gw_applet)
 {
-
     gw_applet->gweather_pref.update_interval = 
     	panel_applet_gconf_get_int(gw_applet->applet, "auto_update_interval", NULL);
     gw_applet->gweather_pref.update_enabled =
@@ -729,17 +1014,13 @@ void gweather_pref_load (GWeatherApplet *gw_applet)
     	panel_applet_gconf_get_bool(gw_applet->applet, "enable_detailed_forecast", NULL);
     gw_applet->gweather_pref.radar_enabled =
     	panel_applet_gconf_get_bool(gw_applet->applet, "enable_radar_map", NULL);
-    gw_applet->gweather_pref.proxy_url =
-    	panel_applet_gconf_get_string(gw_applet->applet, "proxy_url", NULL);
-    gw_applet->gweather_pref.proxy_user =
-    	panel_applet_gconf_get_string(gw_applet->applet, "proxy_user", NULL);
-    gw_applet->gweather_pref.proxy_passwd =
-    	panel_applet_gconf_get_string(gw_applet->applet, "proxy_passwd", NULL);
-    gw_applet->gweather_pref.use_proxy =
-    	panel_applet_gconf_get_bool(gw_applet->applet, "enable_proxy", NULL);
     gw_applet->gweather_pref.location = weather_location_config_read(gw_applet->applet);
-
-	return;
+    gw_applet->gweather_pref.use_custom_radar_url = 
+    	panel_applet_gconf_get_bool(gw_applet->applet, "use_custom_radar_url", NULL);
+    gw_applet->gweather_pref.radar = panel_applet_gconf_get_string (gw_applet->applet,
+    								    "radar",
+    								    NULL);
+    return;
 }
 
 static void help_cb (void)
