@@ -19,18 +19,13 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/* these defines are needed (but missing in GNOME2) */
-#define PIXEL_SIZE_TINY 24
-#define PIXEL_SIZE_SMALL 32
-
-#include <string.h>
 #include <config.h>
+#include <string.h>
 #include <gnome.h>
 #include <panel-applet.h>
 #include "mini-commander_applet.h"
 #include "preferences.h"
 #include "command_line.h"
-#include "terminal.h"
 #include "message.h"
 #include "exec.h"
 #include "about.h"
@@ -39,9 +34,9 @@
 #include "browser-mini.xpm"
 #include "history-mini.xpm"
 
-static gint applet_destroy_signal(GtkWidget *widget, gpointer data);
-static gint applet_detached_signal(GtkWidget *widget, gpointer data);
-static gint applet_attached_signal(GtkWidget *widget, gpointer data);
+static void applet_destroy_signal(GtkWidget *widget, gpointer data);
+static gint applet_detached_signal(GtkHandleBox *hb, GtkWidget *widget, gpointer data);
+static gint applet_attached_signal(GtkHandleBox *hb, GtkWidget *widget, gpointer data);
 static gint applet_orient_changed_cb(GtkWidget *widget, gpointer data);
 static void applet_pixel_size_changed_cb(GtkWidget *widget, int size, gpointer data);
 
@@ -53,31 +48,32 @@ static const BonoboUIVerb mini_commander_menu_verbs[] = {
         BONOBO_UI_VERB_END
 };
 
-static const char mini_commander_menu_xml[] =
-        "<popup name=\"button3\">\n"
-        "   <menuitem name=\"Item 1\" verb=\"Props\" _label=\"Properties\"\n"
-        "             pixtype=\"stock\" pixname=\"gtk-properties\"/>\n"
-        "   <menuitem name=\"Item 2\" verb=\"Help\" _label=\"Help\"\n"
-        "             pixtype=\"stock\" pixname=\"gtk-help\"/>\n"
-        "   <menuitem name=\"Item 3\" verb=\"About\" _label=\"About\"\n"
-        "             pixtype=\"stock\" pixname=\"gnome-stock-about\"/>\n"
-        "</popup>\n";
-
-
-static gint
+static void
 applet_destroy_signal(GtkWidget *widget, gpointer data)
 {
-    /* applet will be destroyed; save settings now */
-    save_session();
-
+    MCData *mcdata = data;
+    PanelApplet *applet = mcdata->applet;
+    GtkTooltips *tooltips;
+	
+    tooltips = g_object_get_data (G_OBJECT (applet), "tooltips");
+    if (tooltips) {
+        g_object_unref (tooltips);
+        g_object_set_data (G_OBJECT (applet), "tooltips", NULL);
+    }
+    
+    
+#if 0 /* Freeing these prevents the applet from restarting - not sure what's up */
+  
+    g_free (mcdata->prop);
+    g_free (mcdata);
+  
+#endif
     /* go on */
-    return FALSE;  
-    widget = NULL;
-    data = NULL;
+    return;  
 }
 
 static gint
-applet_detached_signal(GtkWidget *widget, gpointer data)
+applet_detached_signal(GtkHandleBox *hb, GtkWidget *widget, gpointer data)
 {
     PanelApplet *applet = data;
     properties *prop;
@@ -86,9 +82,9 @@ applet_detached_signal(GtkWidget *widget, gpointer data)
     
     /* applet has been detached; make it smaller */
 
-    gtk_widget_set_usize(GTK_WIDGET(applet),
+    /*gtk_widget_set_usize(GTK_WIDGET(applet),
 			 20,
-			 prop->normal_size_y);
+			 prop->normal_size_y);*/
   
     /* go on */
     return FALSE;  
@@ -97,7 +93,7 @@ applet_detached_signal(GtkWidget *widget, gpointer data)
 }
 
 static gint
-applet_attached_signal(GtkWidget *widget, gpointer data)
+applet_attached_signal(GtkHandleBox *hb, GtkWidget *widget, gpointer data)
 {
     PanelApplet *applet = data;
     properties *prop;
@@ -106,9 +102,9 @@ applet_attached_signal(GtkWidget *widget, gpointer data)
     
     /* applet has been detached; restore original size */
 
-    gtk_widget_set_usize(GTK_WIDGET(applet),
+    /*gtk_widget_set_usize(GTK_WIDGET(applet),
 			 prop->normal_size_x,
-			 prop->normal_size_y);
+			 prop->normal_size_y);*/
   
     /* go on */
     return FALSE;  
@@ -119,6 +115,7 @@ applet_attached_signal(GtkWidget *widget, gpointer data)
 static gint
 applet_orient_changed_cb(GtkWidget *widget, gpointer data)
 {
+    MCData *mcdata = data;
     PanelApplet *applet = data;
     static int counter = 0;
 
@@ -135,45 +132,66 @@ applet_orient_changed_cb(GtkWidget *widget, gpointer data)
 static void
 applet_pixel_size_changed_cb(GtkWidget *widget, int size, gpointer data)
 {
+    MCData *mcdata = data;
     PanelApplet *applet = data;
-    properties *prop;
-    static int counter = 0;
+    properties *prop = mcdata->prop;
 
-    prop = g_object_get_data (G_OBJECT (applet), "prop");
    
-    if(counter++ > 0)
-	show_message((gchar *) _("size changed")); 
+    show_message((gchar *) _("size changed")); 
 
     prop->normal_size_y = size;
-    if(size <= PIXEL_SIZE_TINY)
+    if(size <= GNOME_Vertigo_PANEL_X_SMALL)
 	{
-	  if(counter > 1) /* ignore size-changed-signal at startup */
-	      prop->show_frame = FALSE;
 	    prop->flat_layout = TRUE;
 	} 
-    else if(size <= PIXEL_SIZE_SMALL)
+    else if(size <= GNOME_Vertigo_PANEL_SMALL)
 	{
-	    if(counter > 1) /* ignore size-changed-signal at startup */
-	      prop->show_frame = TRUE;
 	    prop->flat_layout = TRUE;
 	} 
     else
 	{
-	    if(counter > 1) /* ignore size-changed-signal at startup */
-	      prop->show_frame = TRUE;
 	    prop->flat_layout = FALSE;
 	}
 
-    redraw_applet(applet);
+    redraw_applet(mcdata);
     return;
     widget = NULL;
     data = NULL;
 }
 
 void
-redraw_applet(PanelApplet *applet)
+set_atk_name_description(GtkWidget *widget, const gchar *name,
+const gchar *description)
+{	
+    AtkObject *aobj;
+	
+    aobj = gtk_widget_get_accessible(widget);
+    if (GTK_IS_ACCESSIBLE (aobj) == FALSE)
+        return;
+
+    atk_object_set_name(aobj, name);
+    atk_object_set_description(aobj, description);
+}
+
+static gboolean
+button_press_hack (GtkWidget *widget, GdkEventButton *event, gpointer data)
 {
-    properties *prop;
+	PanelApplet *applet = PANEL_APPLET (data);
+
+	if (event->button == 1) {
+		return FALSE;
+	} else {
+		GTK_WIDGET_CLASS (PANEL_APPLET_GET_CLASS (applet))->
+			button_press_event (data, event);
+	}
+	return TRUE;
+}
+
+void
+redraw_applet(MCData *mcdata)
+{
+    PanelApplet *applet = mcdata->applet;
+    properties *prop = mcdata->prop;
     GtkWidget *hbox, *hbox_buttons;
     GtkWidget *button;
     GtkWidget *frame;
@@ -181,15 +199,17 @@ redraw_applet(PanelApplet *applet)
     GtkWidget *handle;
     GtkWidget *icon;
     GtkWidget *vbox;
+    GtkTooltips *tooltips;
+    GdkPixbuf *image;
     int size_frames = 0;
     int size_status_line = 18;
+    gboolean first_time = FALSE;
 
-    static GtkWidget *applet_vbox = NULL;
-    static GtkWidget *applet_inner_vbox = NULL;
-    static int first_time = TRUE;   
+    tooltips = gtk_tooltips_new ();
+    g_object_ref (tooltips);
+    gtk_object_sink (GTK_OBJECT (tooltips));
+    g_object_set_data (G_OBJECT (applet), "tooltips", tooltips); 
     
-    prop = g_object_get_data (G_OBJECT (applet), "prop");
-
     /* recalculate sizes */
     if(prop->show_handle)
 	size_frames += 0;
@@ -199,22 +219,23 @@ redraw_applet(PanelApplet *applet)
 	size_status_line = 0;
     prop->cmd_line_size_y = prop->normal_size_y - size_status_line - size_frames;   
 
-    if(!applet_vbox)
+    if(!mcdata->applet_vbox)
 	{
-	    applet_vbox = gtk_vbox_new(FALSE, 0);
-	    gtk_container_set_border_width(GTK_CONTAINER(applet_vbox), 0);
+	    mcdata->applet_vbox = gtk_vbox_new(FALSE, 0);
+	    gtk_container_set_border_width(GTK_CONTAINER(mcdata->applet_vbox), 0);
+	    first_time = TRUE;
 	}
 
-    if(applet_inner_vbox)
+    if(mcdata->applet_inner_vbox)
       /* clean up */
-      gtk_widget_destroy(GTK_WIDGET(applet_inner_vbox)); 
+      gtk_widget_destroy(GTK_WIDGET(mcdata->applet_inner_vbox)); 
 
-    applet_inner_vbox = gtk_vbox_new(FALSE, 0);
-    gtk_container_set_border_width(GTK_CONTAINER(applet_inner_vbox), 0);
+    mcdata->applet_inner_vbox = gtk_vbox_new(FALSE, 0);
+    gtk_container_set_border_width(GTK_CONTAINER(mcdata->applet_inner_vbox), 0);
     /* in case we get destroyed elsewhere */
-    gtk_signal_connect(GTK_OBJECT(applet_inner_vbox),"destroy",
+    gtk_signal_connect(GTK_OBJECT(mcdata->applet_inner_vbox),"destroy",
 		       GTK_SIGNAL_FUNC(gtk_widget_destroyed),
-		       &applet_inner_vbox);
+		       &mcdata->applet_inner_vbox);
 
 
     /*
@@ -230,23 +251,23 @@ redraw_applet(PanelApplet *applet)
     else
 	vbox = gtk_vbox_new(FALSE, 0);
     gtk_container_set_border_width(GTK_CONTAINER(vbox), 0);
-    
+   
     /* add command line; position: top */
-    init_command_entry(applet);
+    mcdata->entry = init_command_entry(mcdata);
 
 /*     gtk_box_pack_start(GTK_BOX(vbox), entry_command, FALSE, FALSE, 0); */
 
     /* hbox for message label and buttons */
     hbox = gtk_hbox_new(FALSE, 0);
-    
+#ifdef MESSAGES_NOT_NEEDED_FOR_NOW    
     /* add message label */
-    init_message_label(applet);
+    init_message_label(mcdata);
 
     /* do not center text but put it to bottom instead */
     gtk_misc_set_alignment(GTK_MISC(label_message), 0.0, 1.0);
     gtk_box_pack_start(GTK_BOX(hbox), label_message, TRUE, TRUE, 0);
-
-    if(prop->flat_layout) 
+#endif
+    if(prop->flat_layout && (prop->normal_size_y > GNOME_Vertigo_PANEL_X_SMALL)) 
 	hbox_buttons = gtk_vbox_new(TRUE, 0);
     else
 	hbox_buttons = gtk_hbox_new(TRUE, 0);
@@ -256,31 +277,39 @@ redraw_applet(PanelApplet *applet)
     gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		       GTK_SIGNAL_FUNC(show_file_browser_signal),
 		       applet);
+    g_signal_connect (G_OBJECT (button), "button_press_event",
+		      G_CALLBACK (button_press_hack), applet);
     gtk_widget_set_usize(GTK_WIDGET(button), 13, 10);
-    icon = gnome_pixmap_new_from_xpm_d (browser_mini_xpm);
+    image = gdk_pixbuf_new_from_xpm_data (browser_mini_xpm);
+    icon = gtk_image_new_from_pixbuf (image);
     gtk_container_add(GTK_CONTAINER(button), icon);
-#if 0 /* FIXME */
-    applet_widget_set_widget_tooltip(APPLET_WIDGET(applet),
-				     GTK_WIDGET(button),
-				     _("Browser"));
-#endif
+
+    gtk_tooltips_set_tip (tooltips, button, _("Browser"), NULL);
     gtk_box_pack_start(GTK_BOX(hbox_buttons), button, TRUE, TRUE, 0);
+	
+    set_atk_name_description(button, _("Browser"),
+        _("Click this button to start the browser"));
 
     /* add history button */
     button = gtk_button_new();
     gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		       GTK_SIGNAL_FUNC(show_history_signal),
 		       applet);
+    g_signal_connect (G_OBJECT (button), "button_press_event",
+		      G_CALLBACK (button_press_hack), applet);
     gtk_widget_set_usize(GTK_WIDGET(button), 13, 10);
-    icon = gnome_pixmap_new_from_xpm_d (history_mini_xpm);
+    image = gdk_pixbuf_new_from_xpm_data (history_mini_xpm);
+    icon = gtk_image_new_from_pixbuf (image);
     gtk_container_add(GTK_CONTAINER(button), icon);
-#if 0 /* FIXME */
-    applet_widget_set_widget_tooltip(APPLET_WIDGET(applet),
-				     GTK_WIDGET(button),
-				     _("History"));
-#endif
+
+    gtk_tooltips_set_tip (tooltips, button, _("History"), NULL);
     gtk_box_pack_end(GTK_BOX(hbox_buttons), button, TRUE, TRUE, 0);
 
+    set_atk_name_description(button, _("History"),
+        _("Click this button for the list of previous commands"));
+    set_atk_name_description(GTK_WIDGET(applet), _("Mini-Commander applet"),
+        _("This applet adds a command line to the panel"));
+	
     /* add buttons into frame */
     frame = gtk_frame_new(NULL);
     gtk_container_set_border_width(GTK_CONTAINER(frame), 1);
@@ -306,10 +335,10 @@ redraw_applet(PanelApplet *applet)
 	    handle = gtk_handle_box_new();
 	    gtk_signal_connect(GTK_OBJECT(handle), "child_detached",
 			       GTK_SIGNAL_FUNC(applet_detached_signal),
-			       NULL);
+			       applet);
 	    gtk_signal_connect(GTK_OBJECT(handle), "child_attached",
 			       GTK_SIGNAL_FUNC(applet_attached_signal),
-			       NULL);
+			       applet);
 	    if (prop->show_frame)
 		gtk_container_add(GTK_CONTAINER(handle), frame);
 	    else
@@ -323,13 +352,12 @@ redraw_applet(PanelApplet *applet)
 		    gtk_container_add(GTK_CONTAINER(frame2), handle);
 		}
 	    
-	    /* there was trouble with the tooltip */
-	    /* applet_widget_set_tooltip(APPLET_WIDGET(applet),  _("Mini-Commander")); */
+	    gtk_tooltips_set_tip (tooltips, GTK_WIDGET (applet),  _("Command Line"), NULL);
 	    
 	    if (prop->show_frame)
-		gtk_box_pack_start(GTK_BOX(applet_inner_vbox), frame2, TRUE, TRUE, 0);
+		gtk_box_pack_start(GTK_BOX(mcdata->applet_inner_vbox), frame2, TRUE, TRUE, 0);
 	    else
-		gtk_box_pack_start(GTK_BOX(applet_inner_vbox), handle, TRUE, TRUE, 0);
+		gtk_box_pack_start(GTK_BOX(mcdata->applet_inner_vbox), handle, TRUE, TRUE, 0);
 	} 
     else 
 	{
@@ -345,80 +373,75 @@ redraw_applet(PanelApplet *applet)
 		    gtk_frame_set_shadow_type(GTK_FRAME(frame2), GTK_SHADOW_IN);
 		    gtk_container_add(GTK_CONTAINER(frame2), frame);
 		    
-		    gtk_box_pack_start(GTK_BOX(applet_inner_vbox), frame2, TRUE, TRUE, 0);
+		    gtk_box_pack_start(GTK_BOX(mcdata->applet_inner_vbox), frame2, TRUE, TRUE, 0);
 		}
 	    else
-		gtk_box_pack_start(GTK_BOX(applet_inner_vbox), vbox, TRUE, TRUE, 0);
+		gtk_box_pack_start(GTK_BOX(mcdata->applet_inner_vbox), vbox, TRUE, TRUE, 0);
     }
 
-    gtk_box_pack_start(GTK_BOX(applet_vbox), applet_inner_vbox, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(mcdata->applet_vbox), mcdata->applet_inner_vbox, 
+    		       TRUE, TRUE, 0);
 
-    if(first_time)
-#if 0
-	applet_widget_add (APPLET_WIDGET (applet), applet_vbox);
-#endif
-        gtk_container_add(GTK_CONTAINER(applet), applet_vbox);
-    first_time = FALSE;
-
-    gtk_widget_set_usize(GTK_WIDGET(applet), prop->normal_size_x, prop->normal_size_y);
+    if (first_time)
+        gtk_container_add(GTK_CONTAINER(applet), mcdata->applet_vbox);
+  
+    /*gtk_widget_set_usize(GTK_WIDGET(applet), prop->normal_size_x, prop->normal_size_y);*/
 
     /* allow pasting into the input box by packing it after
        applet_widdget_add has bound the middle mouse button (idea taken
        from the applet Web_control by Garrett Smith) */
-#if 1
-    gtk_box_pack_start(GTK_BOX(vbox), entry_command, FALSE, FALSE, 0);
-#else
-    frame = gtk_frame_new(NULL);
-    gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
-    gtk_container_add(GTK_CONTAINER(frame), terminal_zvt);
-    gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
-#endif
 
-    gtk_widget_show_all(applet_vbox);
-    gtk_widget_show_all(applet_inner_vbox);
-  
+    gtk_box_pack_start(GTK_BOX(vbox), mcdata->entry, FALSE, FALSE, 0);
+
     gtk_widget_show_all(GTK_WIDGET (applet));
-    
+
+   
 }
 
-/* int main_(int argc, char **argv) */
 static gboolean
 mini_commander_applet_fill(PanelApplet *applet)
 {
-    properties *prop;
+    MCData *mcdata;
     
+    panel_applet_add_preferences (applet, "/schemas/apps/mini-commander/prefs", NULL);
+    
+    mcdata = g_new0 (MCData, 1);
+    mcdata->applet = applet;
+  
     /* install signal handler */
     init_exec_signal_handler();
 
     g_signal_connect(GTK_OBJECT(applet),
 		     "change_orient",
 		     G_CALLBACK(applet_orient_changed_cb),
-		     NULL);
+		     mcdata);
 
     /*we have to bind change_pixel_size before we do applet_widget_add 
       since we need to get an initial change_pixel_size signal to set our
       initial size, and we get that during the _add call*/
-    g_signal_connect(G_OBJECT(applet),
+	g_signal_connect(G_OBJECT(applet),
 		     "change_size",
 		     G_CALLBACK(applet_pixel_size_changed_cb),
-		     applet);
+		     mcdata);
     
-    prop = load_session();
-    g_object_set_data (G_OBJECT (applet), "prop", prop);
+    mcdata->prop = load_session(mcdata);
+    g_object_set_data (G_OBJECT (applet), "prop", mcdata->prop);
     
     g_signal_connect(G_OBJECT(applet), "destroy",
 		     G_CALLBACK(applet_destroy_signal),
-		     applet); 
-    
-    redraw_applet(applet);
+		     mcdata); 
 
-    panel_applet_setup_menu(PANEL_APPLET(applet),
-			    mini_commander_menu_xml,
+    applet_pixel_size_changed_cb(NULL, panel_applet_get_size (applet), mcdata);
+
+    panel_applet_setup_menu_from_file (applet,
+			    NULL, /* opt. datadir */
+			    "GNOME_MiniCommanderApplet.xml",
+			    NULL,
 			    mini_commander_menu_verbs,
-			    applet);
-      
+			    mcdata);
+#if 0      
     show_message((gchar *) _("ready...")); 
- 
+#endif 
     return TRUE;
 }
 
@@ -437,6 +460,7 @@ mini_commander_applet_factory(PanelApplet *applet,
 }
 
 PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_MiniCommanderApplet_Factory",
+			     PANEL_TYPE_APPLET,
                              "Mini-Commander",
                              "0",
                              mini_commander_applet_factory,
