@@ -1,4 +1,4 @@
-/*  panel-menu.c
+/* panel-menu.c
  * (c) 2001 Chris Phelps
  * Menubar based Panel Applet
  *
@@ -90,7 +90,7 @@ static gboolean panel_menu_accept_entry_drop (PanelMenu *panel_menu,
 
 static gint applet_button_press_cb (GtkWidget *widget, GdkEventButton *event,
 				    PanelMenu *panel_menu);
-static gint applet_destroy_cb (GtkWidget *widget, PanelMenu *panel_menu);
+static void applet_destroy_cb (GtkWidget *widget, PanelMenu *panel_menu);
 static void applet_change_orientation_cb (PanelApplet *applet,
 					  PanelAppletOrient orient,
 					  PanelMenu *panel_menu);
@@ -126,7 +126,7 @@ static const char applet_menu_xml[] =
 	"   <placeholder name=\"ChildMerge\"/>\n"
 	"   <menuitem name=\"Add\" verb=\"Add\" _label=\"Add...\"\n"
 	"             pixtype=\"stock\" pixname=\"gtk-add\"/>\n"
-	"   <menuitem name=\"Properties Item\" verb=\"Properties\" _label=\"Properties ...\"\n"
+	"   <menuitem name=\"Properties Item\" verb=\"Properties\" _label=\"Menu Bar Preferences...\"\n"
 	"             pixtype=\"stock\" pixname=\"gtk-properties\"/>\n"
 	"   <menuitem name=\"Help Item\" verb=\"Help\" _label=\"Help\"\n"
 	"             pixtype=\"stock\" pixname=\"gtk-help\"/>\n"
@@ -134,7 +134,6 @@ static const char applet_menu_xml[] =
 	"             pixtype=\"stock\" pixname=\"gnome-stock-about\"/>\n"
 	"</popup>\n";
 
-
 #if MENU_APPLET_IS_SHLIB
 PANEL_APPLET_BONOBO_SHLIB_FACTORY ("OAFIID:GNOME_PanelMenuApplet_Factory",
 				   PANEL_TYPE_APPLET,
@@ -580,12 +579,14 @@ applet_button_press_cb (GtkWidget *widget, GdkEventButton *event,
 	return TRUE;
 }
 
-static gint
+static void
 applet_destroy_cb (GtkWidget *widget, PanelMenu *panel_menu)
 {
 	PanelMenuEntry *entry;
 	GList *cur;
 
+	destroy_tooltip( widget );
+
 	g_free (panel_menu->profile_id);
 	g_free (panel_menu->applet_id);
 
@@ -599,8 +600,10 @@ applet_destroy_cb (GtkWidget *widget, PanelMenu *panel_menu)
 		entry = (PanelMenuEntry *) cur->data;
 		panel_menu_common_call_entry_destroy (entry);
 	}
-	if (panel_menu->entries)
+	if (panel_menu->entries) {
 		g_list_free (panel_menu->entries);
+	}
+	panel_menu_pixbuf_exit ();
 	g_free (panel_menu);
 }
 
@@ -678,7 +681,10 @@ applet_about_cb (BonoboUIComponent *uic, PanelMenu *panel_menu,
 		pixbuf = gdk_pixbuf_new_from_file (file, NULL);
 	}
 
-	about = gnome_about_new (_("PanelMenu Applet"), "0.0.1", _("(c) 2001 Chris Phelps"), _("The Panel Menu Applet allows you to display customized menubars on your panels."), authors, NULL,	/* documenters */
+	about = gnome_about_new (_("PanelMenu Applet"), "0.0.1",
+				 _("(c) 2001 Chris Phelps"),
+				 _("The Panel Menu Applet allows you to display customized menubars on your panels."),
+				 authors, NULL,	/* documenters */
 				 NULL,	/* translator_credits */
 				 pixbuf);
 
@@ -690,3 +696,70 @@ applet_about_cb (BonoboUIComponent *uic, PanelMenu *panel_menu,
 			  G_CALLBACK (gtk_widget_destroyed), &about);
 	gtk_widget_show (about);
 }
+
+void
+add_tooltip (GtkWidget *widget, gchar *description)
+{
+	GtkTooltips *tooltips;
+
+	tooltips = g_object_get_data (G_OBJECT (widget), "tooltips");
+
+	/* create if not already present */
+	if (!tooltips) {
+		tooltips = gtk_tooltips_new ();
+		g_return_if_fail (tooltips != NULL);
+		g_object_ref (tooltips);
+		gtk_object_sink (GTK_OBJECT (tooltips));
+		g_object_set_data (G_OBJECT (widget), "tooltips", tooltips);
+	}
+
+	gtk_tooltips_set_tip (tooltips, widget, description, NULL);
+}
+
+void
+destroy_tooltip (GtkWidget *object)
+{
+        GtkTooltips *tooltips;
+
+        tooltips = g_object_get_data (G_OBJECT (object), "tooltips");
+        if (tooltips) {
+                g_object_unref (tooltips);
+                g_object_set_data (G_OBJECT (object), "tooltips", NULL);
+        }
+}
+
+/**
+ * set_relation
+ * @widget : The Gtk widget which is labelled by @label
+ * @label : The label for the @widget.
+ * Description : This function establishes atk relation
+ * between a gtk widget and a label.
+ */
+void
+set_relation (GtkWidget *widget, GtkLabel *label)
+{
+	AtkObject *aobject;
+	AtkRelationSet *relation_set;
+	AtkRelation *relation;
+	AtkObject *targets[1];
+
+	g_return_if_fail (GTK_IS_WIDGET(widget));
+	g_return_if_fail (GTK_IS_LABEL(label));
+
+	aobject = gtk_widget_get_accessible (widget);
+
+	/* Return if GAIL is not loaded */
+	if (! GTK_IS_ACCESSIBLE (aobject))
+		return;
+
+	/* Set the ATK_RELATION_LABEL_FOR relation */
+	gtk_label_set_mnemonic_widget (label, widget);
+
+	targets[0] = gtk_widget_get_accessible (GTK_WIDGET (label));
+
+	relation_set = atk_object_ref_relation_set (aobject);
+
+	relation = atk_relation_new (targets, 1, ATK_RELATION_LABELLED_BY);
+	atk_relation_set_add (relation_set, relation);
+	g_object_unref (G_OBJECT (relation));
+}
